CommonButtonHoverStyle class

Constructors

CommonButtonHoverStyle({TextStyle? textStyle, TextStyle? filledTextStyle, Color? color, Color? backgroundColor, Color? borderColor, Gradient? gradient, MouseCursor? mouseCursor, Color? iconColor, double? borderWidth, BorderRadius? borderRadius, List<BoxShadow>? boxShadow})
CommonButtonHoverStyle initialization
const

Properties

backgroundColor Color?
final
borderColor Color?
final
borderRadius BorderRadius?
final
borderWidth double?
final
boxShadow List<BoxShadow>?
final
color Color?
final
filledTextStyle TextStyle?
final
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color?
final
mouseCursor MouseCursor?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
final

Methods

copyWith({TextStyle? textStyle, TextStyle? filledTextStyle, Color? color, Color? backgroundColor, Color? borderColor, Gradient? gradient, MouseCursor? mouseCursor, Color? iconColor, double? borderWidth, BorderRadius? borderRadius, List<BoxShadow>? boxShadow}) CommonButtonHoverStyle
Create copy of this hover style with changes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited