ListDialogStyle class

Constructors

ListDialogStyle({DialogContainerStyle dialogContainerStyle = const DialogContainerStyle(), DialogHeaderStyle dialogHeaderStyle = const DialogHeaderStyle(), DialogFooterStyle dialogFooterStyle = const DialogFooterStyle(), TextFormFieldStyle filterStyle = const TextFormFieldStyle(), CommonButtonStyle optionStyle = const CommonButtonStyle(variant: .textOnly), CommonButtonStyle selectedOptionStyle = const CommonButtonStyle(variant: .filled), double optionsSpacing = kCommonVerticalMarginQuarter})
ListDialogStyle initialization
const

Properties

dialogContainerStyle DialogContainerStyle
final
dialogFooterStyle DialogFooterStyle
final
dialogHeaderStyle DialogHeaderStyle
final
filterStyle TextFormFieldStyle
final
hashCode int
The hash code for this object.
no setterinherited
optionsSpacing double
final
optionStyle CommonButtonStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedOptionStyle CommonButtonStyle
final

Methods

copyWith({DialogContainerStyle? dialogContainerStyle, DialogHeaderStyle? dialogHeaderStyle, DialogFooterStyle? dialogFooterStyle, TextFormFieldStyle? filterStyle, CommonButtonStyle? optionStyle, CommonButtonStyle? selectedOptionStyle, double? optionsSpacing}) ListDialogStyle
Create copy of this tyle with changes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited