SelectionFormFieldStyle class

Constructors

SelectionFormFieldStyle({TextFormFieldStyle inputStyle = const TextFormFieldStyle(), BorderRadius? borderRadius = const BorderRadius.all(.circular(8)), SelectionFormFieldHoverStyle? hoverStyle, MouseCursor mouseCursor = SystemMouseCursors.click, Duration animationDuration = kThemeAnimationDuration, Curve animationCurve = Curves.easeOut})
SelectionFormFieldStyle initialization
const

Properties

animationCurve Curve
final
animationDuration Duration
final
borderRadius BorderRadius?
final
hashCode int
The hash code for this object.
no setterinherited
hoverStyle SelectionFormFieldHoverStyle?
final
inputStyle TextFormFieldStyle
final
mouseCursor MouseCursor
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TextFormFieldStyle? inputStyle, BorderRadius? borderRadius, SelectionFormFieldHoverStyle? hoverStyle, MouseCursor? mouseCursor, Duration? animationDuration, Curve? animationCurve}) SelectionFormFieldStyle
Create copy of this style with changes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited