DialogsStyle class
Constructors
- DialogsStyle({bool fullWidthMobileOnly = true, double? dialogWidth, double? dialogHeight, bool stretchContent = false, GenericDialogStyle genericDialogStyle = const GenericDialogStyle(), ConfirmDialogStyle confirmDialogStyle = const ConfirmDialogStyle(), ListDialogStyle listDialogStyle = const ListDialogStyle()})
-
DialogsStyle initialization
const
Properties
- confirmDialogStyle → ConfirmDialogStyle
-
final
- dialogHeight → double?
-
final
- dialogWidth → double?
-
final
- fullWidthMobileOnly → bool
-
final
- genericDialogStyle → GenericDialogStyle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listDialogStyle → ListDialogStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stretchContent → bool
-
final
Methods
-
copyWith(
{bool? fullWidthMobileOnly, double? dialogWidth, double? dialogHeight, bool? stretchContent, GenericDialogStyle? genericDialogStyle, ConfirmDialogStyle? confirmDialogStyle, ListDialogStyle? listDialogStyle}) → DialogsStyle - Create copy if this style with changes
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited